==> beacon_0_1_4.zip: beacon/beacon/template/default.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="keywords" content="<?php echo $lang['meta_keywords'];?>">
<meta name="OriginalPublicationDate" content="<?php echo $lang['meta_OriginalPublicationDate'];?>">
<meta name="Description" content="<?php echo $lang['meta_Description'];?>">

<title><?php echo $lang['txt_page_title'];?></title>
<style type="text/css">
<!--
@import url(<?php echo $templatePath;?>beacon.css);

-->
</style>
<!--[if IE]>
<style type="text/css">
@import url(<?php echo $templatePath;?>beacon-IE.css);
</style>
<![endif]-->

<script language="JavaScript" src="js/functions.js" type="text/javascript"></script>
<script language="JavaScript" src="speller/spellChecker.js" type="text/javascript"></script>
<script language="JavaScript" type="text/javascript">
	var baseImgURL = '<?php echo $templatePath?>img/';
	
	//takes form elements (text and textarea) and passes to spellchecker
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}

</script>

<link rel="SHORTCUT ICON" href="<?php echo $templatePath;?>img/favicon.ico" />

</head>

<body>

<div style="position:relative; left:20px; top:20px; width:760px">
	
<div align="right" id="base">
	<form action="search.php" method="post">
	<table cellpadding="0" cellspacing="0" border="0">
		<tr>
			<?php
			if (count($lang['language']) > 1) {
				foreach ($lang['language'] as $key => $i):
					if ($key == $_SESSION['language_id']) {
						echo "<td>" . $i . "&nbsp;|&nbsp;</td>";
					}
					else {
						echo "<td><a href=\"index.php?language_id=" . $key . "\">" . $i . "</a></td><td>&nbsp;|&nbsp;</td>";
					}
				endforeach;
			}
			?>
			
			<?php
			if (isset($_SESSION['user_id'])) {
				echo "<td>" . $_SESSION['user_name'] . "</td><td>&nbsp;|&nbsp;</td><td><a href=\"account.php\">" . $lang['href_account'] . "</a></td><td>&nbsp;|&nbsp;</td><td><a href=\"index.php?logoff=1\">" .$lang['txt_logoff'] . "</a><br /></td>";
			}
			else {
				echo "<td><a href=\"admin.php\">" .$lang['href_login_register'] . "</a><br /></td>";
			}
			?>
			
			<td>&nbsp;|&nbsp;</td>
			
			<td nowrap="nowrap">
				<?php echo $lang['href_search'];?><br />
			</td>
			<td>
				<img src="<?php echo $templatePath;?>img/pixel.png" width="6" height="1" alt="" border="0" /><br />
			</td>
			<td>
			<input type="text" name="search_text" size="10" class="searchbox" value="<?php if (isset($search_text)) { echo $search_text;}?>" /><br />
			</td>
			<td>
				<img src="<?php echo $templatePath;?>img/pixel.png" width="6" height="1" alt="" border="0" /><br />
			</td>
			<td>
				<input type="image" src="<?php echo $templatePath;?>img/search.png" /><br />
			<td>
		</tr>
	</table>
	</form>
	
	
</div>

<div style="margin-bottom:30px; margin-top: 10px">
	<a href="index.php"><img src="<?php echo $templatePath;?>img/beacon.png" width="155" height="35" alt="Beacon" border="0" /></a><br />
</div>

<?php
if (isset($log)) {
?>
<div id="box_error">
	<?php
	foreach($log as $key => $i):
		
		$error = $lang['arr_error'][$i[0]];
		
		if (isset($i[1])) {
			$error .= " " . $i[1];
		}
		
		echo "<p>" . $error . "</p>";
		
	endforeach;
	?>
</div>
<?php }?>
	
	
	<table border="0" cellspacing="0" cellpadding="0" width="100%">
		<tr>
			<td valign="top" width="150" id="sidebar">
				<?php
				$menu = $this->menu->selMenu(1);
				
				if (!empty($menu)) {
					foreach($menu as $key => $i):
						if (isset($item) && (($link_type_ids[1] && $item['item_wiki_page'] == $i['menu_link']) || ($link_type_ids[2] && $item['category_id'] == $i['menu_link']))) {
							echo $i['menu_title'];
						}
						else {
							if ($i['menu_link_type_id'] == $link_type_ids['wikipage']) {
								$lnk = "index.php?page=" . $i['menu_link'];
							}
							elseif ($i['menu_link_type_id'] == $link_type_ids['category']) {
								$lnk = "index.php?category=" . $i['menu_link'];
							}
							else {
								$lnk = $i['menu_link'];	
							}
							
							echo "<a href=\"" . $lnk . "\">" . $i['menu_title'] . "</a>";
						}
						echo "<br />";
					endforeach;
				}
				?>
				
				<?php
				$menu_out = "";
				
				if ($this->user->checkPermission($permissions['edit_menu'])) {
					$menu_out .= "<a href=\"admin.php?list_menu=1\">" . $lang['href_edit_menu'] . "</a><br />";
				}
				
				if ($this->user->checkPermission($permissions['edit_item'])) {
					$menu_out .= "<a href=\"admin.php?list_item=1\">" . $lang['href_edit_items'] . "</a><br />";
				}
				
				if ($this->user->checkPermission($permissions['edit_file'])) {
					$menu_out .= "<a href=\"admin.php?list_files=1\">" . $lang['href_edit_files'] . "</a><br />";
				}
				
				if ($this->user->checkPermission($permissions['edit_category'])) {
					$menu_out .= "<a href=\"admin.php?list_categories=1\">" . $lang['href_edit_categories'] . "</a><br />";
				}
				
				if ($this->user->checkPermission($permissions['edit_user'])) {
					$menu_out .= "<a href=\"admin.php?list_users=1\">" . $lang['href_edit_contributors'] . "</a><br />";
				}
				
				if ($this->user->checkPermission($permissions['send_newsletter'])) {
					$menu_out .= "<a href=\"newsletter.php\">" . $lang['href_send_newsletter'] . "</a><br />";
				}
				
				if (!empty($menu_out)) {
					echo "<p><hr />" . $menu_out . "</p>";
				}
				?>
				
				
			</td>
			<td width="20">
				<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" border="0" /><br />
			</td>
			<td valign="top" width="590" id="contents">
				<?php echo $content;?>
			</td>
		</tr>
	</table>
		
	<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="35" alt="" border="0" /><br />
	
	<div id="base" style="margin-left: 150px">
	 	<p align="center">
	 	<?php echo $lang['txt_copyright'];?><br />
	 	</p>
		
		<div align="center">
		<table border="0" cellspacing="0" cellpadding="4">
			<tr>
				<td valign="top">
	 				<table border="0" cellspacing="0" cellpadding="4">
						<tr>
							<td valign="top">
								<a href="rss_feed.php" title="<?php echo $lang['txt_image_title'];?>"><img src="<?php echo $templatePath;?>img/rss.png" width="36" height="15" alt="" border="0" /></a>	
							</td>
							<td>
							<?php
							$menu = $this->menu->selMenu(2);
							
							if (!empty($menu)) {
								foreach($menu as $key => $i):
									if ($i['menu_link_type_id'] == $link_type_ids['wikipage']) {
										$lnk = "index.php?page=" . $i['menu_link'];
									}
									elseif ($i['menu_link_type_id'] == $link_type_ids['category']) {
										$lnk = "index.php?category=" . $i['menu_link'];
									}
									else {
										$lnk = $i['menu_link'];	
									}
									
									echo "<a href=\"" . $lnk . "\">" . $i['menu_title'] . "</a>";
									
									echo "&nbsp;&nbsp;";
								endforeach;
							}
							?>
							</td>
						</tr>
					</table>
				</td>
			</tr>
		</table>
		
		<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" border="0" /><br />
		
		<?php echo $lang['txt_strap'];?><br />
		
		</div>
	</div>
</div>
</body>
</html>

==> beacon_0_1_5.zip: beacon/beacon/template/default.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="keywords" content="<?php echo $lang['meta_keywords'];?>">
<meta name="OriginalPublicationDate" content="<?php echo $lang['meta_OriginalPublicationDate'];?>">
<meta name="Description" content="<?php echo $lang['meta_Description'];?>">

<title><?php echo $lang['txt_page_title'];?></title>
<style type="text/css">
<!--
@import url(<?php echo $templatePath;?>beacon.css);

-->
</style>
<!--[if IE]>
<style type="text/css">
@import url(<?php echo $templatePath;?>beacon-IE.css);
</style>
<![endif]-->

<script language="JavaScript" src="js/functions.js" type="text/javascript"></script>
<script language="JavaScript" src="speller/spellChecker.js" type="text/javascript"></script>
<script language="JavaScript" type="text/javascript">
	var baseImgURL = '<?php echo $templatePath?>img/';
	
	//takes form elements (text and textarea) and passes to spellchecker
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}

</script>

<link rel="SHORTCUT ICON" href="<?php echo $templatePath;?>img/favicon.ico" />

</head>

<body>

<div style="position:relative; left:20px; top:20px; width:760px">
	
<div align="right" id="base">
	<form action="search.php" method="post">
	<table cellpadding="0" cellspacing="0" border="0">
		<tr>
			<?php
			if (count($lang['language']) > 1) {
				foreach ($lang['language'] as $key => $i):
					if ($key == $_SESSION['language_id']) {
						echo "<td>" . $i . "&nbsp;&#124;&nbsp;</td>";
					}
					else {
						echo "<td><a href=\"index.php?language_id=" . $key . "\">" . $i . "</a></td><td>&nbsp;&#124;&nbsp;</td>";
					}
				endforeach;
			}
			?>
			
			<?php
			if (isset($_SESSION['user_id'])) {
				echo "<td>" . $_SESSION['user_name'] . "</td><td>&nbsp;&#124;&nbsp;</td><td><a href=\"account.php\">" . $lang['href_account'] . "</a></td><td>&nbsp;&#124;&nbsp;</td><td><a href=\"index.php?logoff=1\">" .$lang['txt_logoff'] . "</a><br /></td>";
			}
			else {
				echo "<td><a href=\"admin.php\">" .$lang['href_login_register'] . "</a><br /></td>";
			}
			?>
			
			<td>&nbsp;&#124;&nbsp;</td>
			
			<td nowrap="nowrap">
				<?php echo $lang['href_search'];?><br />
			</td>
			<td>
				<img src="<?php echo $templatePath;?>img/pixel.png" width="6" height="1" alt="" border="0" /><br />
			</td>
			<td>
			<input type="text" name="search_text" size="10" class="searchbox" value="<?php if (isset($search_text)) { echo $search_text;}?>" /><br />
			</td>
			<td>
				<img src="<?php echo $templatePath;?>img/pixel.png" width="6" height="1" alt="" border="0" /><br />
			</td>
			<td>
				<input type="image" src="<?php echo $templatePath;?>img/search.png" /><br />
			<td>
		</tr>
	</table>
	</form>
	
	
</div>

<div style="margin-bottom:30px; margin-top: 10px">
	<a href="index.php"><img src="<?php echo $templatePath;?>img/beacon.png" width="155" height="35" alt="Beacon" border="0" /></a><br />
</div>

<?php
if (isset($log)) {
?>
<div id="box_error">
	<?php
	foreach($log as $key => $i):
		
		$error = $lang['arr_error'][$i[0]];
		
		if (isset($i[1])) {
			$error .= " " . $i[1];
		}
		
		echo "<p>" . $error . "</p>";
		
	endforeach;
	?>
</div>
<?php }?>
	
	
	<table border="0" cellspacing="0" cellpadding="0" width="100%">
		<tr>
			<td valign="top" width="150" id="sidebar">
				<?php
				$menu = $this->menu->selMenu(1);
				
				if (!empty($menu)) {
					foreach($menu as $key => $i):
						if (isset($item) && (($link_type_ids[1] && $item['item_wiki_page'] == $i['menu_link']) || ($link_type_ids[2] && $item['category_id'] == $i['menu_link']))) {
							echo $i['menu_title'];
						}
						else {
							if ($i['menu_link_type_id'] == $link_type_ids['wikipage']) {
								$lnk = "index.php?page=" . $i['menu_link'];
							}
							elseif ($i['menu_link_type_id'] == $link_type_ids['category']) {
								$lnk = "index.php?category=" . $i['menu_link'];
							}
							else {
								$lnk = $i['menu_link'];	
							}
							
							echo "<a href=\"" . $lnk . "\">" . $i['menu_title'] . "</a>";
						}
						echo "<br />";
					endforeach;
				}
				?>
				
				<?php
				$menu_out = "";
				
				if ($this->user->checkPermission($permissions['edit_menu'])) {
					$menu_out .= "<a href=\"admin.php?list_menu=1\">" . $lang['href_edit_menu'] . "</a><br />";
				}
				
				if ($this->user->checkPermission($permissions['edit_item'])) {
					$menu_out .= "<a href=\"admin.php?list_item=1\">" . $lang['href_edit_items'] . "</a><br />";
				}
				
				if ($this->user->checkPermission($permissions['edit_file'])) {
					$menu_out .= "<a href=\"admin.php?list_files=1\">" . $lang['href_edit_files'] . "</a><br />";
				}
				
				if ($this->user->checkPermission($permissions['edit_category'])) {
					$menu_out .= "<a href=\"admin.php?list_categories=1\">" . $lang['href_edit_categories'] . "</a><br />";
				}
				
				if ($this->user->checkPermission($permissions['edit_user'])) {
					$menu_out .= "<a href=\"admin.php?list_users=1\">" . $lang['href_edit_contributors'] . "</a><br />";
				}
				
				if ($this->user->checkPermission($permissions['send_newsletter'])) {
					$menu_out .= "<a href=\"newsletter.php\">" . $lang['href_send_newsletter'] . "</a><br />";
				}
				
				if (!empty($menu_out)) {
					echo "<p><hr />" . $menu_out . "</p>";
				}
				?>
				
				
			</td>
			<td width="20">
				<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" border="0" /><br />
			</td>
			<td valign="top" width="590" id="contents">
				<?php echo $content;?>
			</td>
		</tr>
	</table>
		
	<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="35" alt="" border="0" /><br />
	
	<div id="base" style="margin-left: 150px">
	 	<p align="center">
	 	<?php echo $lang['txt_copyright'];?><br />
	 	</p>
		
		<div align="center">
		<table border="0" cellspacing="0" cellpadding="4">
			<tr>
				<td valign="top">
	 				<table border="0" cellspacing="0" cellpadding="4">
						<tr>
							<td valign="top">
								<a href="rss_feed.php" title="<?php echo $lang['txt_image_title'];?>"><img src="<?php echo $templatePath;?>img/rss.png" width="36" height="15" alt="" border="0" /></a>	
							</td>
							<td>
							<?php
							$menu = $this->menu->selMenu(2);
							
							if (!empty($menu)) {
								foreach($menu as $key => $i):
									if ($i['menu_link_type_id'] == $link_type_ids['wikipage']) {
										$lnk = "index.php?page=" . $i['menu_link'];
									}
									elseif ($i['menu_link_type_id'] == $link_type_ids['category']) {
										$lnk = "index.php?category=" . $i['menu_link'];
									}
									else {
										$lnk = $i['menu_link'];	
									}
									
									echo "<a href=\"" . $lnk . "\">" . $i['menu_title'] . "</a>";
									
									echo "&nbsp;&nbsp;";
								endforeach;
							}
							?>
							</td>
						</tr>
					</table>
				</td>
			</tr>
		</table>
		
		<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" border="0" /><br />
		
		<?php echo $lang['txt_strap'];?><br />
		
		</div>
	</div>
</div>
</body>
</html>
